@@ -21,7 +21,7 @@ import json
 import zlib
 import os
 
-VERSION = 2.8
+VERSION = 2.11
 
 def dameRespuestaLlamado(url, data):
 	respuesta = ''
@@ -187,7 +187,8 @@ def timeBlend(token, anchor_ts, blend_source,
               interval_size = 3600,
               consumption_confirmation = 'off',
               missing_values = 'raw',
-              data_format = 'dataframe'):
+              data_format = 'dataframe',
+              print_progress = 1):
 	global VERSION
 	try:
 		if oblender != None:
@@ -210,17 +211,19 @@ def timeBlend(token, anchor_ts, blend_source,
            'agg_output' : interval_output,
            'agg_interval_size' : interval_size,
            'missing_values' : missing_values,
+           'print_progress' : print_progress
         }
         
 		json_parameters_task = {'token' : token, 
                                 'number_of_rows' : len(anchor_ts),
                                 'blend_source' : blend_source, 
                                 'consumption_confirmation' : consumption_confirmation}
-        
+		print_progress = False if 'print_progress' in json_parametros and (json_parametros['print_progress'] == 0 or json_parametros['print_progress'] == 'off') else True
 		confirm, consumption_id = initializeTask(json_parameters_task, url) #'y', 1 #
 		tam_ini = 1000 if 'id_dataset' in blend_source else 350
 		if confirm == 'y':
-			print("Task confirmed. Starting download..")
+			if print_progress:
+				print("Task confirmed. Starting download..")
 			df_resp = None
 			resp_vacio = True
 			universe_size = len(anchor_ts)
@@ -237,7 +240,8 @@ def timeBlend(token, anchor_ts, blend_source,
                               'compress' : 1}).encode()
 				respuesta = dameRespuestaLlamado(url, data)
 				if respuesta['status'] == 'success':
-					print(str(progress * 100) + '%')
+					if print_progress:
+						print(str(progress * 100) + '%')
 					time.sleep(2)
 					if resp_vacio:
 						df_resp = pd.read_json(StringIO(json.dumps(respuesta['df_resp'])), convert_dates=False,convert_axes=False)
@@ -271,7 +275,8 @@ def locationBlend(token, anchor_lat, anchor_lon, blend_source,
               n = 3,
               r = 1000,
               consumption_confirmation = 'off',
-              data_format = 'dataframe'):
+              data_format = 'dataframe',
+              print_progress = 1):
     
 	global VERSION
 	try:
@@ -311,18 +316,20 @@ def locationBlend(token, anchor_lat, anchor_lon, blend_source,
            'blend_type' : blend_type,
            'agg_output' : agg_output,
            'n' : n,
-           'r' : r
+           'r' : r,
+            'print_progress' : print_progress
         }
         
 		json_parameters_task = {'token' : token, 
                                 'number_of_rows' : len(anchor_lat),
                                 'blend_source' : blend_source, 
                                 'consumption_confirmation' : consumption_confirmation}
-        
+		print_progress = False if 'print_progress' in json_parametros and (json_parametros['print_progress'] == 0 or json_parametros['print_progress'] == 'off') else True
 		confirm, consumption_id = initializeTask(json_parameters_task, url) #'y', 1 #
 		tam_ini = 500 
 		if confirm == 'y':
-			print("Task confirmed. Starting download..")
+			if print_progress:
+				print("Task confirmed. Starting download..")
 			df_resp = None
 			resp_vacio = True
 			universe_size = len(anchor_lat)
@@ -340,7 +347,8 @@ def locationBlend(token, anchor_lat, anchor_lon, blend_source,
                               'compress' : 1}).encode()
 				respuesta = dameRespuestaLlamado(url, data)
 				if respuesta['status'] == 'success':
-					print(str(progress * 100) + '%')
+					if print_progress:
+						print(str(progress * 100) + '%')
 					time.sleep(2)
 					if resp_vacio:
 						df_resp = pd.read_json(StringIO(json.dumps(respuesta['df_resp'])), convert_dates=False,convert_axes=False)
@@ -490,7 +498,7 @@ def API_getSampleObservationsWithVectorizer(json_parametros, url):
 	global VERSION
 	confirm, consumption_id = initializeTask(json_parametros, url)
 	if confirm == 'y':
-		print("Task confirmed. Starting download..")
+		#print("Task confirmed. Starting download..")
 		json_parametros['consumption_id'] = consumption_id
 		json_parametros['python_version'] = VERSION
 		return API_genericDownloadCall(json_parametros, url, 'API_getSampleObservationsWithVectorizerPlus', 5, 300)
@@ -504,7 +512,7 @@ def API_getSampleObservationsFromDataset(json_parametros, url):
 	global VERSION
 	confirm, consumption_id = initializeTask(json_parametros, url)
 	if confirm == 'y':
-		print("Task confirmed. Starting download..")
+		#print("Task confirmed. Starting download..")
 		json_parametros['consumption_id'] = consumption_id
 		json_parametros['python_version'] = VERSION
 		return API_genericDownloadCall(json_parametros, url, 'API_getSampleObservationsFromDataset', 25, 600)
@@ -518,7 +526,7 @@ def API_getOpenTextData(json_parametros, url):
 	global VERSION
 	confirm, consumption_id = initializeTask(json_parametros, url)
 	if confirm == 'y':
-		print("Task confirmed. Starting download..")
+		#print("Task confirmed. Starting download..")
 		json_parametros['consumption_id'] = consumption_id
 		json_parametros['python_version'] = VERSION
 		return API_genericDownloadCall(json_parametros, url, 'API_getOpenTextData', 25, 500)
@@ -530,12 +538,14 @@ def API_getOpenTextData(json_parametros, url):
     
 def initializeTask(json_parametros, url):
 	json_parametros['python_version'] = VERSION
+	print_progress = False if 'print_progress' in json_parametros and (json_parametros['print_progress'] == 0 or json_parametros['print_progress'] == 'off') else True
 	data = urlencode({'action' : 'API_initializeTask', 'json' : json.dumps(json_parametros), 'compress' : 1}).encode()
 	details_task = dameRespuestaLlamado(url, data)
 	#print(details_task)
 	consumption_id = details_task['consumption_id']
-	print("Task ID: '" + str(consumption_id) + "'.")
-	print("Total estimated consumption: " + str(round(details_task['details']['total_consumption'],2)) + " processing units.")
+	if print_progress:
+		print("Task ID: '" + str(consumption_id) + "'.")
+		print("Total estimated consumption: " + str(round(details_task['details']['total_consumption'],2)) + " processing units.")
 	consumption_confirmation = json_parametros['consumption_confirmation'] if 'consumption_confirmation' in json_parametros else 0
 	time.sleep(0.5)
 	confirm = input("Continue?  [y] yes \t [n] no") if consumption_confirmation == 'on' else 'y'
@@ -547,6 +557,7 @@ def API_genericDownloadCall(json_parametros, url, action, n_test_observations, s
 	try:
 		start = time.time()
 		test_call = 1 if 'test_call' in json_parametros and (json_parametros['test_call'] == 1 or json_parametros['test_call'] == 'on') else False
+		print_progress = False if 'print_progress' in json_parametros and (json_parametros['print_progress'] == 0 or json_parametros['print_progress'] == 'off') else True
 		if test_call == 1:
 			print("")
 			print('This is a TEST CALL, set "test_call" : "off" or remove to execute service.')
@@ -598,13 +609,15 @@ def API_genericDownloadCall(json_parametros, url, action, n_test_observations, s
 							1 + 1
 					avance = round(((i + 1)/num_pedazos) * 100, 2)
 					if avance >= 100:
-						print(str(avance) + " % completed.")
+						if print_progress:
+							print(str(avance) + " % completed.")
 					else:
-						print(str(avance) + " %")
-						#print("downloading..")
+						if print_progress:
+							print(str(avance) + " %")
 				except Exception as e:
 					#print(str(e))
-					print("Warning: Some observations could not be processed.")
+					if print_progress:
+						print("Warning: Some observations could not be processed.")
 			if 'sample_size' in json_parametros:
 				if int(json_parametros['sample_size']) < df_resp.shape[0]:
 				    drop_indices = np.random.choice(df_resp.index, df_resp.shape[0] - int(json_parametros['sample_size']), replace=False)
